==> google-cloud-sdk-284.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/ai_platform/models/delete.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform models delete command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import models
from googlecloudsdk.api_lib.ml_engine import operations
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import flags
from googlecloudsdk.command_lib.ml_engine import models_util


def _AddDeleteArgs(parser):
  flags.GetModelName().AddToParser(parser)
  flags.GetRegionArg('model').AddToParser(parser)


class Delete(base.DeleteCommand):
  r"""Delete an existing AI Platform model.

  ## EXAMPLES

  To delete all models matching the regular expression `vision[0-9]+`, run:

      $ {parent_command} list --uri \
            --filter 'name ~ vision[0-9]+' |
            xargs -n 1 {command}
  """

  @staticmethod
  def Args(parser):
    _AddDeleteArgs(parser)

  def Run(self, args):
    models_client = models.ModelsClient()
    operations_client = operations.OperationsClient()
    return models_util.Delete(models_client, operations_client, args.model)

==> google-cloud-sdk-286.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/ai_platform/models/delete.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform models delete command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import models
from googlecloudsdk.api_lib.ml_engine import operations
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import endpoint_util
from googlecloudsdk.command_lib.ml_engine import flags
from googlecloudsdk.command_lib.ml_engine import models_util


def _AddDeleteArgs(parser):
  flags.GetModelName().AddToParser(parser)
  flags.GetRegionArg('model').AddToParser(parser)


class Delete(base.DeleteCommand):
  r"""Delete an existing AI Platform model.

  ## EXAMPLES

  To delete all models matching the regular expression `vision[0-9]+`, run:

      $ {parent_command} list --uri \
            --filter 'name ~ vision[0-9]+' |
            xargs -n 1 {command}
  """

  @staticmethod
  def Args(parser):
    _AddDeleteArgs(parser)

  def Run(self, args):
    with endpoint_util.MlEndpointOverrides(region=args.region):
      models_client = models.ModelsClient()
      operations_client = operations.OperationsClient()
      return models_util.Delete(models_client, operations_client, args.model)
